@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 
 from django.db import migrations, models
 
@@ -26,7 +25,7 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='action',
             name='previous_status',
-            field=models.ForeignKey(related_name='+', default=None, blank=True, to='Crm.ActionStatus', null=True),
+            field=models.ForeignKey(related_name='+', default=None, blank=True, to='Crm.ActionStatus', null=True, on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='actiontype',
@@ -36,11 +35,11 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='actionstatustrack',
             name='action',
-            field=models.ForeignKey(to='Crm.Action'),
+            field=models.ForeignKey(to='Crm.Action', on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='actionstatustrack',
             name='status',
-            field=models.ForeignKey(to='Crm.ActionStatus'),
+            field=models.ForeignKey(to='Crm.ActionStatus', on_delete=models.CASCADE),
         ),
     ]
