@@ -3,7 +3,7 @@
 
 from django.conf import settings
 from django.contrib.sites.models import Site
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.test.utils import override_settings
 
 from coop_cms.tests import BeautifulSoup
@@ -43,20 +43,20 @@ class AddressOverloadTest(BaseTestCase):
         city2 = mommy.make(models.City, name='city2')
 
         entity_address = {
-            'address': u'rue Jules Rimet',
-            'address2': u'lot du stade',
-            'address2': u'cité St-Laurent',
-            'cedex': u'Cedex 2',
-            'zip_code': u'12345',
+            'address': 'rue Jules Rimet',
+            'address2': 'lot du stade',
+            'address3': 'cité St-Laurent',
+            'cedex': 'Cedex 2',
+            'zip_code': '12345',
             'city': city1,
         }
 
         contact_address = {
-            'address': u'',
-            'address2': u'',
-            'address2': u'',
-            'cedex': u'',
-            'zip_code': u'',
+            'address': '',
+            'address2': '',
+            'address3': '',
+            'cedex': '',
+            'zip_code': '',
             'city': None,
         }
 
@@ -72,19 +72,19 @@ class AddressOverloadTest(BaseTestCase):
         city2 = mommy.make(models.City, name='city2')
 
         entity_address = {
-            'address': u'rue Jules Rimet',
-            'address2': u'lot du stade',
-            'address2': u'cité St-Laurent',
-            'cedex': u'Cedex 2',
+            'address': 'rue Jules Rimet',
+            'address2': 'lot du stade',
+            'address3': 'cité St-Laurent',
+            'cedex': 'Cedex 2',
             'zip_code': '12345',
             'city': city1,
         }
 
         contact_address = {
-            'address': u'rue des tilleuls',
-            'address2': u'lot des arbres',
-            'address2': u'verrerie',
-            'cedex': u'Cedex 3',
+            'address': 'rue des tilleuls',
+            'address2': 'lot des arbres',
+            'address3': 'verrerie',
+            'cedex': 'Cedex 3',
             'zip_code': '12346',
             'city': city2,
         }
@@ -101,26 +101,26 @@ class AddressOverloadTest(BaseTestCase):
         city2 = mommy.make(models.City, name='city2')
 
         entity_address = {
-            'address': u'rue Jules Rimet',
-            'address2': u'lot du stade',
-            'address2': u'cité St-Laurent',
-            'cedex': u'Cedex 2',
+            'address': 'rue Jules Rimet',
+            'address2': 'lot du stade',
+            'address3': 'cité St-Laurent',
+            'cedex': 'Cedex 2',
             'zip_code': '12345',
             'city': city1,
         }
 
         base_contact_address = {
-            'address': u'rue des tilleuls',
-            'address2': u'lot des arbres',
-            'address2': u'verrerie',
-            'cedex': u'Cedex 3',
+            'address': 'rue des tilleuls',
+            'address2': 'lot des arbres',
+            'address3': 'verrerie',
+            'cedex': 'Cedex 3',
             'zip_code': '12346',
             'city': city2,
         }
 
         for (key, value) in base_contact_address.items():
             #create a dict with same keys but blank values
-            contact_address = dict([(k, u'') for k in base_contact_address.keys()])
+            contact_address = dict([(k, '') for k in base_contact_address.keys()])
             contact_address[key] = value
             if key != 'city':
                 contact_address['city'] = None
@@ -158,7 +158,7 @@ class SingleContactTest(BaseTestCase):
         self.assertEqual(john_doe.lastname, "Doe")
         self.assertEqual(john_doe.firstname, "John")
         self.assertEqual(john_doe.entity.is_single_contact, True)
-        self.assertEqual(john_doe.entity.name, u"doe john")
+        self.assertEqual(john_doe.entity.name, "doe john")
 
     def test_add_single_contact_existing_city(self):
         url = reverse('crm_add_single_contact')
@@ -204,6 +204,29 @@ class SingleContactTest(BaseTestCase):
         self.assertEqual(john_doe.city.name, data['city'])
         self.assertEqual(john_doe.city.parent, zone)
 
+    def test_add_single_contact_new_city_three_digits_code(self):
+        url = reverse('crm_add_single_contact')
+        zone = mommy.make(models.Zone, code="974")
+        data = {
+            'lastname': "Doe",
+            'firstname': 'John',
+            'zip_code': '97440',
+            'city': "Saint-Clotilde"
+        }
+        response = self.client.post(url, data=data, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+
+        self.assertEqual(models.Contact.objects.count(), 1)
+        john_doe = models.Contact.objects.all()[0]
+        self.assertEqual(john_doe.lastname, "Doe")
+        self.assertEqual(john_doe.firstname, "John")
+        self.assertEqual(john_doe.entity.is_single_contact, True)
+        self.assertEqual(john_doe.city.name, data['city'])
+        self.assertEqual(john_doe.city.parent, zone)
+
     def test_add_single_contact_unknown_code(self):
         url = reverse('crm_add_single_contact')
         data = {
@@ -285,7 +308,7 @@ class ContactEntitiesSuggestListTestCase(BaseTestCase):
         response = self.client.get(reverse('crm_get_entities')+'?term=c')
         self.assertEqual(302, response.status_code)
         # login url without lang prefix
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_contacts_not_logged(self):
@@ -293,7 +316,7 @@ class ContactEntitiesSuggestListTestCase(BaseTestCase):
         response = self.client.get(reverse('crm_get_contacts')+'?term=c')
         self.assertEqual(302, response.status_code)
         # login url without lang prefix
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_entities(self):
@@ -334,7 +357,6 @@ class ContactEntitiesSuggestListTestCase(BaseTestCase):
         c2 = mommy.make(models.Contact, lastname="aaa", entity=e1)
         c3 = mommy.make(models.Contact, lastname="bbb", entity=e2)
 
-
         response = self.client.get(reverse('crm_get_contact_id')+"?name="+c1.lastname)
         self.assertEqual(200, response.status_code)
         self.assertContains(response, c1.id)
@@ -421,6 +443,122 @@ class ViewContactsTest(BaseTestCase):
         self.assertNotContains(response, e3.name)
         self.assertNotContains(response, c3.lastname)
 
+    def test_view_contacts_filter_not_a_letter(self):
+        e1 = mommy.make(models.Entity, name="123")
+        c1 = e1.default_contact
+        c1.lastname = "A{0}A".format(c1.id)
+        c1.save()
+
+        e2 = mommy.make(models.Entity, is_single_contact=True, name="124")
+        c2 = e2.default_contact
+        c2.lastname = "125{0}A".format(c2.id)
+        c2.save()
+
+        e3 = mommy.make(models.Entity, name="Abc")
+        c3 = e3.default_contact
+        c3.lastname = "A{0}A".format(c3.id)
+        c3.save()
+
+        url = reverse('crm_view_entities_list')+"?filter=~"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, e1.name)
+        self.assertContains(response, c1.lastname)
+        self.assertNotContains(response, e2.name)
+        self.assertContains(response, c2.lastname)
+        self.assertNotContains(response, e3.name)
+        self.assertNotContains(response, c3.lastname)
+
+    def test_view_contacts_group_single_contact(self):
+        e1 = mommy.make(models.Entity)
+        c1 = e1.default_contact
+        c1.lastname = "#Contact{0}#".format(c1.id)
+        c1.save()
+
+        e2 = mommy.make(models.Entity, is_single_contact=True)
+        c2 = e2.default_contact
+        c2.lastname = "#Contact{0}#".format(c2.id)
+        c2.save()
+
+        g1 = mommy.make(models.Group, on_contacts_list=True)
+        g1.contacts.add(c2)
+        g1.save()
+        g2 = mommy.make(models.Group, on_contacts_list=False)
+        g2.contacts.add(c2)
+        g2.save()
+        g3 = mommy.make(models.Group, on_contacts_list=True)
+
+        url = reverse('crm_view_entities_list')
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, e1.name)
+        self.assertContains(response, c1.lastname)
+        self.assertNotContains(response, e2.name)
+        self.assertContains(response, c2.lastname)
+        self.assertContains(response, g1.name)
+        self.assertNotContains(response, g2.name)
+        self.assertNotContains(response, g3.name)
+
+    def test_view_contacts_group_contact(self):
+        e1 = mommy.make(models.Entity)
+        c1 = e1.default_contact
+        c1.lastname = "#Contact{0}#".format(c1.id)
+        c1.save()
+
+        e2 = mommy.make(models.Entity, is_single_contact=True)
+        c2 = e2.default_contact
+        c2.lastname = "#Contact{0}#".format(c2.id)
+        c2.save()
+
+        g1 = mommy.make(models.Group, on_contacts_list=True)
+        g1.contacts.add(c1)
+        g1.save()
+        g2 = mommy.make(models.Group, on_contacts_list=False)
+        g2.contacts.add(c1)
+        g2.save()
+        g3 = mommy.make(models.Group, on_contacts_list=True)
+
+        url = reverse('crm_view_entities_list')
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, e1.name)
+        self.assertContains(response, c1.lastname)
+        self.assertNotContains(response, e2.name)
+        self.assertContains(response, c2.lastname)
+        self.assertContains(response, g1.name)
+        self.assertNotContains(response, g2.name)
+        self.assertNotContains(response, g3.name)
+
+    def test_view_contacts_group_entity(self):
+        e1 = mommy.make(models.Entity)
+        c1 = e1.default_contact
+        c1.lastname = "#Contact{0}#".format(c1.id)
+        c1.save()
+
+        e2 = mommy.make(models.Entity, is_single_contact=True)
+        c2 = e2.default_contact
+        c2.lastname = "#Contact{0}#".format(c2.id)
+        c2.save()
+
+        g1 = mommy.make(models.Group, on_contacts_list=True)
+        g1.entities.add(e1)
+        g1.save()
+        g2 = mommy.make(models.Group, on_contacts_list=False)
+        g2.entities.add(e1)
+        g2.save()
+        g3 = mommy.make(models.Group, on_contacts_list=True)
+
+        url = reverse('crm_view_entities_list')
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, e1.name)
+        self.assertContains(response, c1.lastname)
+        self.assertNotContains(response, e2.name)
+        self.assertContains(response, c2.lastname)
+        self.assertContains(response, g1.name)
+        self.assertNotContains(response, g2.name)
+        self.assertNotContains(response, g3.name)
+
 
 class ContactViewUrlTest(BaseTestCase):
     """Test the get_view_url method of contact"""
@@ -540,7 +678,7 @@ class EditContactTest(BaseTestCase):
         }
         response = self.client.post(url, data=data)
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
         contact = models.Contact.objects.get(id=contact.id)
@@ -563,7 +701,7 @@ class EditContactTest(BaseTestCase):
         response = self.client.post(url, data=data)
 
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
         contact = models.Contact.objects.get(id=contact.id)
@@ -650,9 +788,9 @@ class EditContactTest(BaseTestCase):
         c = mommy.make(models.Contact)
         url = reverse('crm_edit_contact', args=[c.id])
         data = {
-            'lastname': u'Mémé',
-            'firstname': u'Pépé',
-            "email": u"pepe@mémé.fr"
+            'lastname': 'Mémé',
+            'firstname': 'Pépé',
+            "email": "pepe@mémé.fr"
         }
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
@@ -671,9 +809,9 @@ class EditContactTest(BaseTestCase):
         c = mommy.make(models.Contact)
         url = reverse('crm_edit_contact', args=[c.id])
         data = {
-            'lastname': u'Mémé',
-            'firstname': u'Pépé',
-            "email": u"pépé@mémé.fr"
+            'lastname': 'Mémé',
+            'firstname': 'Pépé',
+            "email": "pépé@mémé.fr"
         }
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
@@ -685,12 +823,12 @@ class EditContactTest(BaseTestCase):
         self.assertNotEqual(c.firstname, data['firstname'])
         self.assertNotEqual(c.email, data['email'])
 
-    @override_settings(SECRET_KEY=u"super-héros")
+    @override_settings(SECRET_KEY="super-héros")
     def test_create_contact_uuid(self):
         data = {
-            'lastname': u'Mémé',
-            'firstname': u'Pépé',
-            "email": u"pepe@mémé.fr"
+            'lastname': 'Mémé',
+            'firstname': 'Pépé',
+            "email": "pepe@mémé.fr"
         }
         c = mommy.make(models.Contact, **data)
 
@@ -871,15 +1009,15 @@ class EditContactSameAsTest(BaseTestCase):
 
     def test_edit_contact_invalid(self):
         """view edit contact form"""
-        same_contact = mommy.make(models.Contact, lastname=u'Dupond', firstname=u'Paul', email=u'contact@abc.fr')
+        same_contact = mommy.make(models.Contact, lastname='Dupond', firstname='Paul', email='contact@abc.fr')
 
         contact = mommy.make(models.Contact, lastname='', firstname='', email='')
         url = reverse('crm_edit_contact', args=[contact.id])
 
         data = {
-            'lastname': u'Durand',
-            'firstname': u'Pierre',
-            'email': u'contact@def.fr',
+            'lastname': 'Durand',
+            'firstname': 'Pierre',
+            'email': 'contact@def.fr',
             'same_as_suggestions': same_contact.id
         }
         response = self.client.post(url, data=data)
@@ -906,9 +1044,9 @@ class EditContactSameAsTest(BaseTestCase):
         url = reverse('crm_edit_contact', args=[contact.id])
 
         data = {
-            'lastname': u'Durand',
-            'firstname': u'Pierre',
-            'email': u'contact@def.fr',
+            'lastname': 'Durand',
+            'firstname': 'Pierre',
+            'email': 'contact@def.fr',
             'same_as_suggestions': "hjkhk"
         }
         response = self.client.post(url, data=data)
@@ -931,9 +1069,9 @@ class EditContactSameAsTest(BaseTestCase):
         url = reverse('crm_edit_contact', args=[contact.id])
 
         data = {
-            'lastname': u'Durand',
-            'firstname': u'Pierre',
-            'email': u'contact@def.fr',
+            'lastname': 'Durand',
+            'firstname': 'Pierre',
+            'email': 'contact@def.fr',
             'same_as_suggestions': contact.id + 1
         }
         response = self.client.post(url, data=data)
@@ -1008,6 +1146,137 @@ class EditContactSameAsTest(BaseTestCase):
         self.assertEqual(contact.same_as_priority, 2)
 
 
+class EditContactEmailVerifiedTest(BaseTestCase):
+    """It should be possible to edit a contact"""
+    fixtures = ['zones.json', ]
+
+    def test_add_contact_email_verified(self):
+        st1 = mommy.make(models.SubscriptionType)
+        st2 = mommy.make(models.SubscriptionType)
+
+        url = reverse('crm_add_single_contact')
+        data = {
+            'lastname': 'Dupond',
+            'firstname': 'Paul',
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(200, response.status_code)
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+
+        contact = models.Contact.objects.get(lastname=data['lastname'], firstname=data['firstname'])
+        self.assertEqual(contact.email_verified, False)
+
+    def test_add_contact_email_verified_set(self):
+        st1 = mommy.make(models.SubscriptionType)
+        st2 = mommy.make(models.SubscriptionType)
+
+        url = reverse('crm_add_single_contact')
+        data = {
+            'lastname': 'Dupond',
+            'firstname': 'Paul',
+            'email_verified': False,
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(200, response.status_code)
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+
+        contact = models.Contact.objects.get(lastname=data['lastname'], firstname=data['firstname'])
+        self.assertEqual(contact.email_verified, False)  # Email verified can not be changed from this form
+
+    def test_view_edit_contact_email_verified(self):
+        contact = mommy.make(models.Contact, email_verified=False)
+        response = self.client.get(reverse('crm_edit_contact', args=[contact.id]))
+        self.assertEqual(200, response.status_code)
+        soup = BeautifulSoup(response.content)
+        fields = soup.select('#id_email_verified')
+        self.assertEqual(1, len(fields))
+        field = fields[0]
+        self.assertEqual(field.attrs.get('checked'), None)  # not checked
+        self.assertEqual(field.attrs.get('disabled'), 'disabled')
+
+    def test_view_edit_contact_email_verified_set(self):
+        contact = mommy.make(models.Contact, email_verified=True)
+        response = self.client.get(reverse('crm_edit_contact', args=[contact.id]))
+        self.assertEqual(200, response.status_code)
+        soup = BeautifulSoup(response.content)
+        fields = soup.select('#id_email_verified')
+        self.assertEqual(1, len(fields))
+        field = fields[0]
+        self.assertEqual(field.attrs.get('checked'), '')  # checked
+        self.assertEqual(field.attrs.get('disabled'), 'disabled')
+
+    def test_edit_contact_email_verified(self):
+        contact = mommy.make(models.Contact, email_verified=False)
+        url = reverse('crm_edit_contact', args=[contact.id])
+        data = {
+            'lastname': 'Dupond',
+            'firstname': 'Paul',
+            'city': models.City.objects.get(name="Paris").id,
+            # email_verified is disabled and should not be sent by the browser
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(200, response.status_code)
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+        next_url = reverse('crm_view_contact', args=[contact.id])
+        self.assertContains(response, "<script>")
+        self.assertContains(response, next_url)
+
+        contact = models.Contact.objects.get(id=contact.id)
+        self.assertEqual(contact.lastname, data['lastname'])
+        self.assertEqual(contact.firstname, data['firstname'])
+        self.assertEqual(contact.city.id, data['city'])
+        self.assertEqual(contact.email_verified, False)
+
+    def test_edit_contact_email_verified_set(self):
+        contact = mommy.make(models.Contact, email_verified=True)
+        url = reverse('crm_edit_contact', args=[contact.id])
+        data = {
+            'lastname': 'Dupond',
+            'firstname': 'Paul',
+            'city': models.City.objects.get(name="Paris").id,
+            # email_verified is disabled and should not be sent by the browser
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(200, response.status_code)
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+        next_url = reverse('crm_view_contact', args=[contact.id])
+        self.assertContains(response, "<script>")
+        self.assertContains(response, next_url)
+
+        contact = models.Contact.objects.get(id=contact.id)
+        self.assertEqual(contact.lastname, data['lastname'])
+        self.assertEqual(contact.firstname, data['firstname'])
+        self.assertEqual(contact.city.id, data['city'])
+        self.assertEqual(contact.email_verified, True)
+
+    def test_edit_contact_email_verified_set_no_changed(self):
+        contact = mommy.make(models.Contact, email_verified=True)
+        url = reverse('crm_edit_contact', args=[contact.id])
+        data = {
+            'lastname': 'Dupond',
+            'firstname': 'Paul',
+            'city': models.City.objects.get(name="Paris").id,
+            'email_verified': False,   # email_verified should not be changed even if browser send something
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(200, response.status_code)
+        errors = BeautifulSoup(response.content).select('.field-error')
+        self.assertEqual(len(errors), 0)
+        next_url = reverse('crm_view_contact', args=[contact.id])
+        self.assertContains(response, "<script>")
+        self.assertContains(response, next_url)
+
+        contact = models.Contact.objects.get(id=contact.id)
+        self.assertEqual(contact.lastname, data['lastname'])
+        self.assertEqual(contact.firstname, data['firstname'])
+        self.assertEqual(contact.city.id, data['city'])
+        self.assertEqual(contact.email_verified, True)
+
+
 class EditContactSubscriptionTest(BaseTestCase):
     """It should be possible to edit a contact"""
     fixtures = ['zones.json', ]
@@ -1047,7 +1316,9 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
@@ -1071,7 +1342,9 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
@@ -1079,7 +1352,7 @@ class EditContactSubscriptionTest(BaseTestCase):
 
         soup.select(f1)[0]["checked"]
         self.assertRaises(KeyError, lambda: soup.select(f2)[0]["checked"])
-        soup.select(f3)[0]["checked"]
+        self.assertRaises(KeyError, lambda: soup.select(f3)[0]["checked"])
 
     @override_settings(BALAFON_SUBSCRIPTION_DEFAULT_VALUE=False)
     def test_view_add_contact_subscriptions(self):
@@ -1093,13 +1366,15 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
         self.assertEqual(1, len(soup.select(f3)))
 
-        #Is not checked
+        # Is not checked
         self.assertRaises(KeyError, lambda: soup.select(f1)[0]["checked"])
         self.assertRaises(KeyError, lambda: soup.select(f2)[0]["checked"])
         self.assertRaises(KeyError, lambda: soup.select(f3)[0]["checked"])
@@ -1116,13 +1391,15 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
         self.assertEqual(1, len(soup.select(f3)))
 
-        #Is not checked
+        # Is not checked
         self.assertRaises(KeyError, lambda: soup.select(f1)[0]["checked"])
         self.assertRaises(KeyError, lambda: soup.select(f2)[0]["checked"])
         self.assertRaises(KeyError, lambda: soup.select(f3)[0]["checked"])
@@ -1139,13 +1416,15 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
         self.assertEqual(1, len(soup.select(f3)))
 
-        #Is checked
+        # Is checked
         soup.select(f1)[0]["checked"]
         soup.select(f2)[0]["checked"]
         soup.select(f3)[0]["checked"]
@@ -1162,13 +1441,15 @@ class EditContactSubscriptionTest(BaseTestCase):
         self.assertEqual(200, response.status_code)
         soup = BeautifulSoup(response.content)
 
-        f1, f2, f3 = '#id_subscription_{0}'.format(st1.id), '#id_subscription_{0}'.format(st2.id), '#id_subscription_{0}'.format(st3.id)
+        f1 = '#id_subscription_{0}'.format(st1.id)
+        f2 = '#id_subscription_{0}'.format(st2.id)
+        f3 = '#id_subscription_{0}'.format(st3.id)
 
         self.assertEqual(1, len(soup.select(f1)))
         self.assertEqual(1, len(soup.select(f2)))
         self.assertEqual(1, len(soup.select(f3)))
 
-        #Is checked
+        # Is checked
         soup.select(f1)[0]["checked"]
         soup.select(f2)[0]["checked"]
         soup.select(f3)[0]["checked"]
