@@ -257,9 +257,9 @@ class ActionArchiveTest(BaseTestCase):
     def test_in_charge_filter(self):
         """view actions of the month in charge filter"""
 
-        user_joe = mommy.make(models.TeamMember, name="Joe")
-        user_jack = mommy.make(models.TeamMember, name="Jack")
-        user_will = mommy.make(models.TeamMember, name="Will")
+        user_joe = mommy.make(models.TeamMember, name="Joe", ordering=1)
+        user_jack = mommy.make(models.TeamMember, name="Jack", ordering=2)
+        user_will = mommy.make(models.TeamMember, name="Will", ordering=3)
 
         action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=datetime.now(), in_charge=user_joe)
         action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=datetime.now(), in_charge=user_joe)
@@ -699,6 +699,82 @@ class ActionArchiveTest(BaseTestCase):
         pos = [content.find(subject) for subject in subjects]
         self.assertEqual(pos, list(sorted(pos)))
 
+    def test_action_filter_name(self):
+        """view actions of the month incharge filter"""
+        now = datetime(2016, 10, 10, 12, 0)
+
+        action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=now + timedelta(days=1))
+        action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=now + timedelta(days=2))
+        action3 = mommy.make(models.Action, subject="#ACT3#", planned_date=now - timedelta(days=1))
+        action4 = mommy.make(models.Action, subject="#ACT4#", planned_date=now - timedelta(days=3))
+        action5 = mommy.make(models.Action, subject="#ACT5#", planned_date=now)
+
+        entity1 = mommy.make(models.Entity, name="Dupond")
+        entity2 = mommy.make(models.Entity, name="Dupal")
+        entity3 = entity2
+        entity4 = mommy.make(models.Entity, name="Bernard")
+        entity5 = mommy.make(models.Entity, name="Chausson")
+
+        actions = [action1, action2, action3, action4, action5]
+        entities = [entity1, entity2, entity3, entity4, entity5]
+
+        for action, entity in zip(actions, entities):
+            action.entities.add(entity)
+            action.save()
+
+        url = reverse(
+            'crm_actions_of_month', args=[now.year, now.month]
+        ) + "?filter=o3&name=Dup"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        actions = [action3, action2, action1]
+        subjects = [action.subject for action in actions]
+        for subject in subjects:
+            self.assertContains(response, subject)
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
+        self.assertEqual(pos, list(sorted(pos)))
+
+    def test_action_filter_name_entity_and_contacts(self):
+        """view actions of the month incharge filter"""
+        now = datetime(2016, 10, 10, 12, 0)
+
+        action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=now + timedelta(days=1))
+        action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=now + timedelta(days=2))
+        action3 = mommy.make(models.Action, subject="#ACT3#", planned_date=now - timedelta(days=1))
+        action4 = mommy.make(models.Action, subject="#ACT4#", planned_date=now - timedelta(days=3))
+        action5 = mommy.make(models.Action, subject="#ACT5#", planned_date=now)
+
+        entity1 = mommy.make(models.Entity, name="Dupond")
+        entity2 = mommy.make(models.Entity, name="Alain")
+        contact = mommy.make(models.Contact, lastname='Dupal', entity=entity2)
+        entity3 = entity2
+        entity4 = mommy.make(models.Entity, name="Bernard")
+        entity5 = mommy.make(models.Entity, name="Chausson")
+
+        actions = [action1, action3, action4, action5]
+        entities = [entity1, entity3, entity4, entity5]
+
+        action2.contacts.add(contact)
+        for action, entity in zip(actions, entities):
+            action.entities.add(entity)
+            action.save()
+
+        url = reverse(
+            'crm_actions_of_month', args=[now.year, now.month]
+        ) + "?filter=o3&name=Dup"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        actions = [action1, action2]
+        subjects = [action.subject for action in actions]
+        for subject in subjects:
+            self.assertContains(response, subject)
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
+        self.assertEqual(pos, list(sorted(pos)))
+
     def test_view_not_planned_action_anonymous(self):
         """make sure not display for anonymous users"""
         mommy.make(models.Action, subject="#ACT1#")
