@@ -3,10 +3,10 @@
 
 import json
 
-from django.core.urlresolvers import reverse
 from django.contrib.auth.decorators import user_passes_test
 from django.http import HttpResponse, Http404, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
+from django.urls import reverse
 
 from balafon.Crm import models
 from balafon.permissions import can_access
