@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from django.test import TestCase
 from django.contrib.auth.models import User
 
-from coop_cms.utils import RequestManager
+from balafon.unit_tests import TestCase
 
 
 class BaseTestCase(TestCase):
 
     def setUp(self):
-        RequestManager().clean()
+        super(BaseTestCase, self).setUp()
         self.user = User.objects.create(username="toto")
         self.user.set_password("abc")
         self.user.is_staff = True
