@@ -29,9 +29,11 @@ from balafon.Crm.models import Contact, Action, ActionType, Subscription
 from balafon.Crm.signals import new_subscription
 from balafon.Emailing import models, forms
 from balafon.Emailing.settings import (
-    is_subscribe_enabled, is_email_subscribe_enabled, get_subscription_form
+    is_subscribe_enabled, is_email_subscribe_enabled, get_subscription_form, notify_subscription_on_confirmation
+)
+from balafon.Emailing.utils import (
+    get_emailing_context, send_verification_email, EmailSendError, patch_emailing_html, send_notification_email
 )
-from balafon.Emailing.utils import get_emailing_context, send_verification_email, EmailSendError, patch_emailing_html
 
 
 @user_passes_test(can_access)
@@ -102,13 +104,18 @@ def new_newsletter(request):
                 template = form.cleaned_data["template"]
                 content = form.cleaned_data["content"]
                 source_url = form.cleaned_data["source_url"]
+                site = form.cleaned_data["site"]
                 go_to_edit = False
                 if not content:
                     content = _("Enter the text of your newsletter here")
                     go_to_edit = True
 
                 newsletter = Newsletter.objects.create(
-                    subject=subject, template=template, content=content, source_url=source_url
+                    subject=subject,
+                    template=template,
+                    content=content,
+                    source_url=source_url,
+                    site=site
                 )
 
                 if go_to_edit:
@@ -348,7 +355,10 @@ def subscribe_error(request, contact_uuid):
 
 def email_verification(request, contact_uuid):
     """handle click on verification link in email verification email"""
-    contact = get_object_or_404(Contact, uuid=contact_uuid)
+    try:
+        contact = Contact.all_objects.get(uuid=contact_uuid)
+    except (Contact.DoesNotExist, Contact.MultipleObjectsReturned):
+        raise Http404
     subscription_type_names = [
         subscription.subscription_type.name for subscription in contact.subscription_set.all()
     ]
@@ -358,9 +368,17 @@ def email_verification(request, contact_uuid):
     if not my_company:
         my_company = getattr(settings, 'BALAFON_MY_COMPANY', '')
 
+    entity = contact.entity
+    entity.confirmed = True
+    entity.save()
+    contact.confirmed = True
     contact.email_verified = True
     contact.save()
 
+    if notify_subscription_on_confirmation():
+        # send an email
+        send_notification_email(request, contact, [], '')
+
     if redirect_to:
         return HttpResponseRedirect(redirect_to)
     else:
@@ -404,6 +422,10 @@ class SubscribeView(View):
     def is_enabled(self):
         return is_subscribe_enabled()
 
+    @staticmethod
+    def require_confirmation():
+        return False
+
     def dispatch(self, request, *args, **kwargs):
         """make possible to disable this view from settings"""
         if not self.is_enabled():
@@ -451,6 +473,12 @@ class SubscribeView(View):
         form = form_class(request.POST, request.FILES, **self.get_form_kwargs())
         if form.is_valid():
             contact = form.save(request)
+            if self.require_confirmation():
+                contact.confirmed = False
+                contact.save()
+                entity = contact.entity
+                entity.confirmed = False
+                entity.save()
             try:
                 subscription_queryset = contact.subscription_set.filter(accept_subscription=True)
 
@@ -489,6 +517,10 @@ class EmailSubscribeView(SubscribeView):
     def is_enabled(self):
         return is_email_subscribe_enabled()
 
+    @staticmethod
+    def require_confirmation():
+        return True
+
     def get_success_url(self, contact):
         """where to redirect when form is valid"""
         return reverse('emailing_subscribe_email_done')
