@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
-from django.utils.safestring import mark_safe
+
 from django import template
-register = template.Library()
-from datetime import date
 
 from balafon.utils import logger
 from django.db.models import Q
 from balafon.Search.utils import get_date_bounds
 
+
+register = template.Library()
+
+
 @register.filter
 def get_actions(contact, search_data):
     try:
