@@ -88,6 +88,21 @@ class StoreManagementActionType(models.Model):
         return "{0}".format(self.action_type)
 
 
+class PaymentMode(models.Model):
+    name = models.CharField(max_length=100, verbose_name=_('name'))
+    code = models.CharField(max_length=100, verbose_name=_('code'))
+    is_active = models.BooleanField(default=True, verbose_name=_('is active'))
+    ordering = models.IntegerField(default=0, verbose_name=_('ordering'))
+
+    class Meta:
+        verbose_name = _("Payment mode")
+        verbose_name_plural = _("Payment modes")
+        ordering = ['ordering', 'id']
+
+    def __str__(self):
+        return self.name
+
+
 class VatRate(models.Model):
     """Tax : A VAT rate"""
     rate = models.DecimalField(verbose_name=_("vat rate"), max_digits=4, decimal_places=2)
@@ -339,7 +354,10 @@ class Voucher(models.Model):
 
     @property
     def label(self):
-        return ugettext('Voucher {0} : Discount {1}%').format(self.code, self.rate.normalize())
+        rate = str(self.rate or 0)
+        if '.' in rate:
+            rate = rate.rstrip('0').rstrip('.')
+        return ugettext('Voucher {0} : Discount {1}%').format(self.code, rate)
 
 
 class Brand(models.Model):
@@ -949,6 +967,9 @@ class Sale(models.Model):
     )
     delivery_details = models.TextField(blank=True, default='')  # This may be public (on sale document)
     details = models.TextField(blank=True, default='')  # This should be private
+    payment_mode = models.ForeignKey(
+        PaymentMode, blank=True, default=None, null=True, on_delete=models.CASCADE, verbose_name=_("payment mode"),
+    )
 
     def get_references_text(self):
         """This text will be added at the bottom of the commercial document"""
@@ -1300,3 +1321,4 @@ def freeze_readonly_action(sender, instance, created, **kwargs):
 
 
 post_save.connect(freeze_readonly_action, sender=Action)
+
