@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 """unit testing"""
 
-from bs4 import BeautifulSoup
 from datetime import datetime, date, time, timedelta
 from decimal import Decimal
 import logging
 
 from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
-from django.test import TestCase
-from django.utils.translation import ugettext as _
+from django.urls import reverse
 
+from coop_cms.tests import BeautifulSoup
 from model_mommy import mommy
 from rest_framework import status
 from rest_framework.test import APITestCase, APIClient
 
+from balafon.unit_tests import TestCase
 from balafon.Crm.models import ActionType
 from balafon.Store import models
 
@@ -82,7 +81,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family)
         article1 = mommy.make(models.StoreItem, category=category1, pre_tax_price=Decimal(10), vat_rate=vat)
@@ -123,7 +122,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family)
         article1 = mommy.make(models.StoreItem, category=category1, pre_tax_price=Decimal(10), vat_rate=vat)
@@ -168,7 +167,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family)
         article1 = mommy.make(models.StoreItem, category=category1, pre_tax_price=Decimal(10), vat_rate=vat)
@@ -216,7 +215,7 @@ class SalesByCategoryTest(BaseTestCase):
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
 
         category1 = mommy.make(models.StoreItemCategory, parent=family)
@@ -314,7 +313,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family)
         tag1 = mommy.make(models.StoreItemTag)
@@ -388,7 +387,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family)
         category2 = mommy.make(models.StoreItemCategory, icon='blabla', parent=family)
@@ -450,7 +449,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family1 = mommy.make(models.StoreItemCategory, parent=None)
         family2 = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family1)
@@ -515,7 +514,7 @@ class SalesByCategoryTest(BaseTestCase):
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family1 = mommy.make(models.StoreItemCategory, parent=None)
         family2 = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family1)
@@ -580,7 +579,7 @@ class SalesByCategoryTest(BaseTestCase):
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
         family1 = mommy.make(models.StoreItemCategory, parent=None)
         family2 = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, parent=family1)
@@ -644,7 +643,7 @@ class SalesByCategoryTest(BaseTestCase):
         """It should return all sales data"""
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
 
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, icon='test', parent=family)
@@ -705,7 +704,7 @@ class SalesByCategoryTest(BaseTestCase):
     def test_total_sales(self):
         """It should return all sales data"""
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
@@ -774,7 +773,7 @@ class SalesByCategoryTest(BaseTestCase):
     def test_total_sales_no_code(self):
         """It should return all sales data"""
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
@@ -845,8 +844,8 @@ class SalesByCategoryTest(BaseTestCase):
 
         vat = mommy.make(models.VatRate, rate=Decimal(10))
 
-        code_internet = models.SaleAnalysisCode.objects.get_or_create(name=u'Internet')[0]
-        code_shop = mommy.make(models.SaleAnalysisCode, name=u'Shop')
+        code_internet = models.SaleAnalysisCode.objects.get_or_create(name='Internet')[0]
+        code_shop = mommy.make(models.SaleAnalysisCode, name='Shop')
 
         family = mommy.make(models.StoreItemCategory, parent=None)
         category1 = mommy.make(models.StoreItemCategory, icon='test', parent=family)
@@ -925,15 +924,12 @@ class ExtraSaleTest(TestCase):
     """Test that it is possible to add 'extra-sales'"""
 
     def setUp(self):
-        logging.disable(logging.CRITICAL)
+        super(ExtraSaleTest, self).setUp()
         self.user = User.objects.create(username="toto", is_active=True, is_staff=True)
         self.user.set_password("abc")
         self.user.save()
         self._login()
 
-    def tearDown(self):
-        logging.disable(logging.NOTSET)
-
     def _login(self):
         self.client.login(username="toto", password="abc")
 
@@ -959,9 +955,9 @@ class ExtraSaleTest(TestCase):
 
         self.assertEqual(response.status_code, 200)
 
-        self.assertEqual(
-            '<script>$.colorbox.close(); window.location="{0}";</script>'.format(redirect_url),
-            response.content
+        self.assertContains(
+            response,
+            '<script>$.colorbox.close(); window.location="{0}";</script>'.format(redirect_url)
         )
 
         self.assertEqual(models.Sale.objects.count(), 1)
@@ -1023,7 +1019,7 @@ class ExtraSaleTest(TestCase):
         self.user.save()
 
         url = reverse('store_add_extra_sale')
-        auth_url = reverse('django.contrib.auth.views.login')[3:]
+        auth_url = reverse('login')[3:]
 
         action_type = mommy.make(ActionType)
         vat_rate = mommy.make(models.VatRate, rate=Decimal(10))
@@ -1049,7 +1045,7 @@ class ExtraSaleTest(TestCase):
         self.client.logout()
 
         url = reverse('store_add_extra_sale')
-        auth_url = reverse('django.contrib.auth.views.login')[3:]
+        auth_url = reverse('login')[3:]
 
         action_type = mommy.make(ActionType)
         vat_rate = mommy.make(models.VatRate, rate=Decimal(10))
@@ -1074,9 +1070,6 @@ class ExtraSaleTest(TestCase):
 class StatIndexTest(TestCase):
     """Test that it is possible to view stats index"""
 
-    def setUp(self):
-        logging.disable(logging.CRITICAL)
-
     def _create_user(self, is_staff=True):
         self.user = User.objects.create(username="toto", is_active=True, is_staff=is_staff)
         self.user.set_password("abc")
