@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 """unit testing"""
 
-from bs4 import BeautifulSoup
 from decimal import Decimal
 
 from django.contrib.auth.models import User
 from django.contrib.sites.models import Site
-from django.core.urlresolvers import reverse
-from django.test import TestCase
+from django.urls import reverse
 from django.utils.translation import ugettext as _
 
+from coop_cms.tests import BeautifulSoup
 from model_mommy import mommy
 
+from balafon.unit_tests import TestCase
 from balafon.Crm.models import Action, ActionStatus, ActionType, Contact, Entity
 from balafon.Crm.tests import BaseTestCase
 from balafon.Store import models
@@ -28,6 +28,7 @@ class ViewCommercialDocumentTest(TestCase):
 
     def setUp(self):
         """before each test"""
+        super(ViewCommercialDocumentTest, self).setUp()
         user = mommy.make(User, is_active=True, is_staff=True, is_superuser=False)
         user.set_password('abc')
         user.save()
@@ -36,6 +37,7 @@ class ViewCommercialDocumentTest(TestCase):
 
     def tearDown(self):
         """after each test"""
+        super(ViewCommercialDocumentTest, self).tearDown()
         self.client.logout()
 
     def test_view_no_sale_action_type(self):
@@ -133,6 +135,25 @@ class ViewCommercialDocumentTest(TestCase):
 
         self.assertEqual(response.context['is_read_only'], True)
 
+    def test_view_frozen_read_only(self):
+        """It should display as read only"""
+
+        action_type = mommy.make(ActionType)
+        action_status = mommy.make(ActionStatus)
+
+        action = mommy.make(Action, type=action_type, status=action_status, frozen=True)
+
+        store_type = mommy.make(models.StoreManagementActionType, action_type=action_type, template_name='')
+
+        mommy.make(models.Sale, action=action)
+
+        url = reverse('store_view_sales_document', args=[action.id])
+        response = self.client.get(url)
+
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(response.context['is_read_only'], True)
+
     def test_view_status_change(self):
         """It should display as writable"""
 
@@ -185,7 +206,7 @@ class ViewCommercialDocumentTest(TestCase):
         response = self.client.get(url)
 
         self.assertEqual(response.status_code, 302)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) > 0)
 
     def test_view_values(self):
@@ -194,7 +215,7 @@ class ViewCommercialDocumentTest(TestCase):
         store_action_type = mommy.make(models.StoreManagementActionType)
         action = mommy.make(Action, type=store_action_type.action_type)
 
-        item = mommy.make(models.SaleItem, sale=action.sale, text=u'Promo été', quantity=1, pre_tax_price=10)
+        item = mommy.make(models.SaleItem, sale=action.sale, text='Promo ETE', quantity=1, pre_tax_price=10)
 
         url = reverse('store_view_sales_document', args=[action.id])
         response = self.client.get(url)
@@ -209,7 +230,7 @@ class ViewCommercialDocumentTest(TestCase):
         action = mommy.make(Action, type=store_action_type.action_type)
 
         item = mommy.make(
-            models.SaleItem, sale=action.sale, item=store_item, text=u'Promo été', quantity=1, pre_tax_price=10
+            models.SaleItem, sale=action.sale, item=store_item, text='Promo ETE', quantity=1, pre_tax_price=10
         )
 
         url = reverse('store_view_sales_document', args=[action.id])
@@ -226,7 +247,24 @@ class ViewCommercialDocumentTest(TestCase):
 
         self.assertNotEqual(action.uuid, '')
 
-        item = mommy.make(models.SaleItem, sale=action.sale, text=u'Promo été', quantity=1, pre_tax_price=10)
+        item = mommy.make(models.SaleItem, sale=action.sale, text='Promo ETE', quantity=1, pre_tax_price=10)
+
+        self.client.logout()
+        url = reverse('store_view_sales_document_public', args=[action.uuid])
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, item.text)
+
+    def test_view_public_utf8(self):
+        """It should display item text"""
+
+        action_type = mommy.make(ActionType, generate_uuid=True)
+        mommy.make(models.StoreManagementActionType, action_type=action_type)
+        action = mommy.make(Action, type=action_type)
+
+        self.assertNotEqual(action.uuid, '')
+
+        item = mommy.make(models.SaleItem, sale=action.sale, text='Promo été', quantity=1, pre_tax_price=10)
 
         self.client.logout()
         url = reverse('store_view_sales_document_public', args=[action.uuid])
@@ -264,12 +302,62 @@ class ViewCommercialDocumentTest(TestCase):
         action.contacts.add(contact1)
         action.save()
 
-        mommy.make(models.SaleItem, sale=action.sale, text=u'Promo été', quantity=1, pre_tax_price=10)
+        mommy.make(models.SaleItem, sale=action.sale, text='Promo été', quantity=1, pre_tax_price=10)
 
         url = reverse('store_view_sales_document_pdf', args=[action.id])
         response = self.client.get(url)
         self.assertEqual(200, response.status_code)
 
+    def test_view_pdf_make_action_readonly(self):
+        """It should display item text"""
+
+        status1 = mommy.make(ActionStatus)
+        status2 = mommy.make(ActionStatus)
+        status3 = mommy.make(ActionStatus)
+
+        store_action_type = mommy.make(models.StoreManagementActionType)
+        action = mommy.make(Action, type=store_action_type.action_type, status=status1)
+        store_action_type.default_readonly_status = status3
+        store_action_type.readonly_status.add(status2, status3)
+        store_action_type.save()
+
+        contact1 = mommy.make(Contact, lastname='abc' * 10)
+        action.contacts.add(contact1)
+        action.save()
+
+        mommy.make(models.SaleItem, sale=action.sale, text='Promo été', quantity=1, pre_tax_price=10)
+
+        url = reverse('store_view_sales_document_pdf', args=[action.id])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+        action  = Action.objects.get(id=action.id)
+        self.assertEqual(action.status, status3)
+
+    def test_view_pdf_action_already_readonly(self):
+        """It should display item text"""
+
+        status1 = mommy.make(ActionStatus)
+        status2 = mommy.make(ActionStatus)
+        status3 = mommy.make(ActionStatus)
+
+        store_action_type = mommy.make(models.StoreManagementActionType)
+        action = mommy.make(Action, type=store_action_type.action_type, status=status2)
+        store_action_type.default_readonly_status = status3
+        store_action_type.readonly_status.add(status2, status3)
+        store_action_type.save()
+
+        contact1 = mommy.make(Contact, lastname='abc' * 10)
+        action.contacts.add(contact1)
+        action.save()
+
+        mommy.make(models.SaleItem, sale=action.sale, text='Promo été', quantity=1, pre_tax_price=10)
+
+        url = reverse('store_view_sales_document_pdf', args=[action.id])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+        action  = Action.objects.get(id=action.id)
+        self.assertEqual(action.status, status2)
+
     def test_view_public_pdf(self):
         """It should display item text"""
 
@@ -284,7 +372,7 @@ class ViewCommercialDocumentTest(TestCase):
         self.assertNotEqual(action.uuid, '')
         self.client.logout()
 
-        mommy.make(models.SaleItem, sale=action.sale, text=u'Promo été', quantity=1, pre_tax_price=10)
+        mommy.make(models.SaleItem, sale=action.sale, text='Promo été', quantity=1, pre_tax_price=10)
 
         url = reverse('store_view_sales_document_pdf_public', args=[action.uuid])
         response = self.client.get(url)
@@ -326,9 +414,7 @@ class ActionMailtoTest(BaseTestCase):
         action.contacts.add(contact)
         action.save()
         self.assertEqual(
-            action.mail_to, 'mailto:"{0}" <{1}>?subject={2}&body='.format(
-                contact.fullname, contact.email, action.subject,
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_entity(self):
@@ -339,9 +425,7 @@ class ActionMailtoTest(BaseTestCase):
         action.entities.add(entity)
         action.save()
         self.assertEqual(
-            action.mail_to, 'mailto:"{0}" <{1}>?subject={2}&body='.format(
-                entity.name, entity.email, action.subject,
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_entity_contact(self):
@@ -352,9 +436,7 @@ class ActionMailtoTest(BaseTestCase):
         action.contacts.add(entity.default_contact)
         action.save()
         self.assertEqual(
-            action.mail_to, 'mailto:{0}?subject={1}&body='.format(
-                entity.email, action.subject,
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_several(self):
@@ -370,9 +452,7 @@ class ActionMailtoTest(BaseTestCase):
 
         action.save()
         self.assertEqual(
-            action.mail_to, 'mailto:{0},{1}?subject={2}&body='.format(
-                entity.email, contact.email, action.subject,
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_twice(self):
@@ -389,9 +469,7 @@ class ActionMailtoTest(BaseTestCase):
         action.save()
 
         self.assertEqual(
-            action.mail_to, 'mailto:{0}?subject={1}&body='.format(
-                entity.email, action.subject,
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_uuid(self):
@@ -403,7 +481,7 @@ class ActionMailtoTest(BaseTestCase):
         action.contacts.add(contact)
         action.save()
 
-        body = _(u"Here is a link to your {0}: {1}{2}").format(
+        body = _("Here is a link to your {0}: {1}{2}").format(
             action_type.name,
             "http://" + Site.objects.get_current().domain,
             reverse('store_view_sales_document_public', args=[action.uuid])
@@ -413,9 +491,7 @@ class ActionMailtoTest(BaseTestCase):
         self.assertEqual(contact.firstname, '')
 
         self.assertEqual(
-            action.mail_to, 'mailto:{0}?subject={1}&body={2}'.format(
-                contact.email, action.subject, body
-            )
+            action.mail_to, reverse('crm_mailto_action', args=[action.id])
         )
 
     def test_mail_to_no_email(self):
@@ -443,7 +519,7 @@ class EditSaleActionTest(BaseTestCase):
     """It should display edit action correctly"""
 
     def test_edit_action_calculated_amount(self):
-        """edit with caculated amount"""
+        """edit with calculated amount"""
         contact = mommy.make(Contact)
 
         action_type = mommy.make(ActionType, is_amount_calculated=False)
@@ -482,12 +558,11 @@ class EditSaleActionTest(BaseTestCase):
         action_type = ActionType.objects.get(id=action_type.id)
         self.assertEqual(action_type.is_amount_calculated, True)
 
-        url = reverse('crm_create_action', args=[0, 0]) + "?type={0}".format(action_type.id)
+        url = reverse('crm_create_action_of_type', args=[0, 0, action_type.id])
         response = self.client.get(url)
         self.assertEqual(200, response.status_code)
 
         soup = BeautifulSoup(response.content)
-
         fields = soup.select("#id_amount")
         self.assertEqual(len(fields), 1)
 
@@ -547,7 +622,8 @@ class CloneSaleActionTest(BaseTestCase):
         original_action = models.Action.objects.get(type=action_type_1)
         new_action = models.Action.objects.get(type=action_type_2)
 
-        self.assertEqual(response.content, 'reload: {0}'.format(reverse('crm_edit_action', args=[new_action.id])))
+        content = response.content.decode('utf-8')
+        self.assertEqual(content, 'reload: {0}'.format(reverse('crm_edit_action', args=[new_action.id])))
 
         self.assertEqual(original_action.subject, new_action.subject)
         self.assertEqual(new_action.parent, original_action)
@@ -628,7 +704,8 @@ class CloneSaleActionTest(BaseTestCase):
         original_action = models.Action.objects.get(type=action_type_1)
         new_action = models.Action.objects.get(type=action_type_2)
 
-        self.assertEqual(response.content, 'reload: {0}'.format(reverse('crm_edit_action', args=[new_action.id])))
+        content = response.content.decode('utf-8')
+        self.assertEqual(content, 'reload: {0}'.format(reverse('crm_edit_action', args=[new_action.id])))
 
         self.assertEqual(original_action.subject, new_action.subject)
         self.assertEqual(new_action.parent, original_action)
